#############
Aldryn Events
#############


Aldryn Categories provides `Aldryn <http://aldryn.com>`_-compatible
hierarchical categories/taxonomies for your Django project.

Aldryn Categories allows you to organise arbitrary objects in a hierarchical
fashion using common Django fields and widgets.

Aldryn Categories is `open-source software <https://github.com/aldryn/aldryn-categories>`_.

.. toctree::
   :maxdepth: 2

   introduction/index
   release/index
   development.rst
